@@ -179,6 +179,7 @@ class ReadabilityCore(object):
         items = []
 
         response = self._get_http_resource(key, params=kwargs)
+
         response = self._resource_deserialize(response)
 
         meta = response.get('meta')
@@ -254,13 +255,14 @@ class Readability(ReadabilityCore):
         return self._get_resource(('articles', id), Article)
 
 
-    def get_bookmarks(self, archive=None, favorite=None, domain=None, limit=None, **filters):
+    def get_bookmarks(self, archive=None, favorite=None, domain=None, order=None, limit=None, **filters):
         """Gets a list of bookmarks."""
 
         filters.update(
             archive=archive,
             favorite=archive,
             domain=domain,
+            order=order
         )
 
         filters = to_api(
@@ -360,6 +362,50 @@ class Readability(ReadabilityCore):
         return self.get_bookmark(resource)
 
 
+    def new_user(self, username, password, email):
+        """Adds given user."""
+
+        r = self._post_resource(('users'),
+            username=username,
+            password=password,
+            email=email)
+        print r
+
+
+
+class ReadabilityShortner(object):
+    """Readability Shortner."""
+
+    def __init__(self):
+        super(ReadabilityShortner, self).__init__()
+
+    def shorten(self, url):
+        # POST to settings.shorner_url
+
+        import httplib2
+        h = httplib2.Http()
+        url = settings.shorner_url % (' urls')
+        params = urllib.urlencode({'url': url})
+        # r, content =  self.client.request(url, method='POST', body=params)
+        resp, content = h.request(url, method='POST', body=params)
+        print resp
+        print content
+        # assert resp.status == 200
+        # assert resp['content-type'] == 'text/html'
+        # print url
+        return url
+
+
+
+
+
+
+
+
+
+
+
+
 # ----------
 # Exceptions
 # ----------
@@ -370,7 +416,7 @@ class APIError(Exception):
             self.msg = self.__doc__
         else:
             self.msg = msg
-            
+
         self.response = response
 
     def __str__(self):
@@ -378,7 +424,7 @@ class APIError(Exception):
             return "%s - response: %s" % (repr(self.msg), repr(self.response))
         else:
             return repr(self.msg)
-        
+
 class PermissionsError(APIError):
     """You do not have proper permission."""
 
@@ -393,6 +439,6 @@ class MissingError(APIError):
 
 class BadRequestError(APIError):
     """The request could not be understood due to bad syntax. Check your request and try again."""
-    
+
 class ServerError(APIError):
-    """The server encountered an error and was unable to complete your request."""
\ No newline at end of file
+    """The server encountered an error and was unable to complete your request."""
